<?php

/**
 * @file
 *  Theme functions for master.
 */

/**
 * Default theme implementation for master_tableselect.
 *
 * @param array $element
 *   a form or form element
 */
function theme_master_tableselect($element) {
  $header = $element['#header'];
  $columns = $element['#columns'];

  $output = '';
  $output .= drupal_render($element['options']);

  $rows = array();
  foreach (element_children($element) as $child) {
    if (!empty($element[$child])) {
      $row = array();
      foreach ($columns as $column) {
        $row[] = (empty($element[$child][$column])) ? '' : drupal_render($element[$child][$column]);
      }
      $rows[] = $row;
    }
  }

  // If rows are given, add tabelselect.
  if (!empty($rows)) {
    $ts_header_cell = theme('table_select_header_cell');
    $header[0] = is_array($header[0]) ? $header[0] : array('data' => $header[0]);
    $header[0] = array_merge($header[0], (is_array($ts_header_cell)) ? $ts_header_cell : array('data' => $ts_header_cell));
  }
  else {
    $rows[] = array(array('data' => $element['#empty'], 'colspan' => count($columns)));
  }

  $output .= theme('table', $header, $rows);
  $output .= drupal_render($element);
  return $output;
}


/**
 * Theme a list for components retrieved from the module object.
 * @param object $feature
 *   the feature/module object provided from e.g. features_get_module()
 * @return string
 *   Rendered string representation.
 */
function theme_master_features_components($feature) {
  if (!empty($feature->info['features'])) {
    $output = array();
    foreach ($feature->info['features'] as $component => $items) {
      $count = count($items);
      $output[] = format_plural($count, '@component (%count item)', '@component (%count items)', array('@component' => $component, '%count' => $count));
    }
    $count = count($output);
    return '<strong>'. format_plural($count, '@count component', '@count components', array('@count' => $count)) .'</strong>: '. implode(', ', $output);
  }
  return t('No feature components.');
}
